#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_LDIV_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_LDIV_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/ldiv.hpp>

#endif
